summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--recordmydesktop/doc/recordmydesktop.12
-rw-r--r--recordmydesktop/include/rmdfunc.h4
-rw-r--r--recordmydesktop/src/Makefile.am2
-rw-r--r--recordmydesktop/src/parseargs.c8
-rw-r--r--recordmydesktop/src/rmd_rescue.c (renamed from recordmydesktop/src/rmd_restore.c)2
5 files changed, 9 insertions, 9 deletions
diff --git a/recordmydesktop/doc/recordmydesktop.1 b/recordmydesktop/doc/recordmydesktop.1
index 2113cfe..015d1b1 100644
--- a/recordmydesktop/doc/recordmydesktop.1
+++ b/recordmydesktop/doc/recordmydesktop.1
@@ -352,7 +352,7 @@ Misc Options:
.br
.TP
.B
- \-restore path_to_data
+ \-rescue path_to_data
Encode cache data from a previous session, into an Ogg/Theora+Vorbis
file. The filename will be the one that was chosen initially.
Any other option specified with this one will be implicitly ignored
diff --git a/recordmydesktop/src/Makefile.am b/recordmydesktop/src/Makefile.am
index 46d2e7a..09b77b0 100644
--- a/recordmydesktop/src/Makefile.am
+++ b/recordmydesktop/src/Makefile.am
@@ -35,7 +35,7 @@ recordmydesktop_SOURCES= recordmydesktop.c\
rmd_error.c\
rmd_frame.c\
rmd_timer.c\
- rmd_restore.c
+ rmd_rescue.c
INCLUDES= $(all_includes) -I$(top_srcdir)/include
diff --git a/recordmydesktop/src/parseargs.c b/recordmydesktop/src/parseargs.c
index cebaf17..cb20ea2 100644
--- a/recordmydesktop/src/parseargs.c
+++ b/recordmydesktop/src/parseargs.c
@@ -101,7 +101,7 @@ int ParseArgs(int argc,char **argv,ProgArgs *arg_return){
"\t-s_quality n\t\tDesired audio quality(-1 to 10).\n\n"
"Misc Options:\n"
- "\t-restore path_to_data\tRestore (encode) data from a previous session.\n"
+ "\t-rescue path_to_data\tEncode data from a previous, crashed, session.\n"
"\t--no-wm-check\t\tDo not try to detect"
" the window manager(and set options according to it)\n"
@@ -517,13 +517,13 @@ int ParseArgs(int argc,char **argv,ProgArgs *arg_return){
}
i++;
}
- else if(!strcmp(argv[i],"-restore")){
+ else if(!strcmp(argv[i],"-rescue")){
if(i+1<argc){
- int ex_st=rmdRestore(argv[i+1]);
+ int ex_st=rmdRescue(argv[i+1]);
exit(ex_st);
}
else{
- fprintf(stderr,"Argument Usage: -restore path_to_data\n");
+ fprintf(stderr,"Argument Usage: -rescue path_to_data\n");
return 1;
}
i++;
diff --git a/recordmydesktop/src/rmd_restore.c b/recordmydesktop/src/rmd_rescue.c
index 3cba0db..3552103 100644
--- a/recordmydesktop/src/rmd_restore.c
+++ b/recordmydesktop/src/rmd_rescue.c
@@ -29,7 +29,7 @@
#include <recordmydesktop.h>
-int rmdRestore(const char *path){
+int rmdRescue(const char *path){
int i=0,
width,
© All Rights Reserved
diff --git a/recordmydesktop/include/rmdfunc.h b/recordmydesktop/include/rmdfunc.h
index 30fe68d..f7afe3b 100644
--- a/recordmydesktop/include/rmdfunc.h
+++ b/recordmydesktop/include/rmdfunc.h
@@ -819,7 +819,7 @@ int ReadSpecsFile(ProgData *pdata);
/*
* Restore a previous recording, found in
* the given path.
*
* \param path Path to the cache folder.
@@ -827,7 +827,7 @@ int ReadSpecsFile(ProgData *pdata);
* \returns 0 on Success, 1 on failure
*
*/
-int rmdRestore(const char *path);
+int rmdRescue(const char *path);
#endif
@@ -819,7 +819,7 @@ int ReadSpecsFile(ProgData *pdata);
/*
- * Restore a previous recording, found in
+ * Rescue a previous recording, found in
* the given path.
*